@@ -80,7 +80,7 @@ get.ArAr.age <- function(Ar40Ar39,sAr40Ar39,J,sJ,exterr=TRUE){
 
 # x an object of class \code{ArAr} returns a matrix of 40Ar/39Ar-ages
 # and their uncertainties. jcu = J-constant uncertainties.
-ArAr.age <- function(x,jcu=TRUE,exterr=TRUE,i=NA,sigdig=NA){
+ArAr.age <- function(x,jcu=TRUE,exterr=TRUE,i=NA,sigdig=NA,i2i=FALSE){
     if (!jcu) x$J[2] <- 0
     ns <- nrow(x$x)
     out <- matrix(0,ns,2)
@@ -89,16 +89,26 @@ ArAr.age <- function(x,jcu=TRUE,exterr=TRUE,i=NA,sigdig=NA){
     sAr4036 <- x$x[,"errAr40Ar36"]
     Ar4039 <- 1/x$x[,"Ar39Ar40"]
     sAr4039 <- x$x[,"errAr39Ar40"]/x$x[,"Ar39Ar40"]^2
-    Ar4039x <- Ar4039-iratio("Ar40Ar36")[1]/x$x[,"Ar39Ar36"]
+    if (i2i){
+        fit <- isochron.ArAr(x,plot=FALSE,exterr=exterr,inverse=FALSE)
+        Ar4039x <- Ar4039 - fit$a[1]/x$x[,"Ar39Ar36"]
+    } else {
+        Ar4039x <- Ar4039-iratio("Ar40Ar36")[1]/x$x[,"Ar39Ar36"]
+    }
     J <- matrix(0,1,3)
     E <- matrix(0,3,3)
     for (j in 1:ns) {
         covmat <- get.covmat.ArAr(x,j)
         J[1,1] <- -1/x$x[j,"Ar39Ar40"]^2
-        J[1,2] <- iratio("Ar40Ar36")[1]/x$x[j,"Ar39Ar36"]^2
         J[1,3] <- -1/x$x[j,"Ar39Ar36"]
         E[1:2,1:2] <- covmat[c("Ar39Ar40","Ar39Ar36"),c("Ar39Ar40","Ar39Ar36")]
-        E[3,3] <- iratio("Ar40Ar36")[2]^2
+        if (i2i) {
+            J[1,2] <- fit$a[1]/x$x[j,"Ar39Ar36"]^2
+            if (exterr) E[3,3] <- fit$a[2]^2
+        } else {
+            J[1,2] <- iratio("Ar40Ar36")[1]/x$x[j,"Ar39Ar36"]^2
+            if (exterr) E[3,3] <- iratio("Ar40Ar36")[2]^2
+        }
         sAr4039x <- sqrt(J %*% E %*% t(J))
         tt <- get.ArAr.age(Ar4039x[j],sAr4039x,x$J[1],x$J[2],exterr=exterr)
         t.out <- roundit(tt[1],tt[2],sigdig=sigdig)
